Package: maplegend
Title: Legends for Maps
Version: 0.6.3
Authors@R: c(person("Timothée", "Giraud", email = "timothee.giraud@cnrs.fr",
    role = c("cre","aut"), comment = c(ORCID = "0000-0002-1932-3323")))
Description: Create legends for maps and other graphics. Thematic maps need to
    be accompanied by legible legends to be fully comprehensible. This package
    offers a wide range of legends useful for cartography, some of which may
    also be useful for other types of graphics. 
License: GPL-3
Depends: R (>= 4.1.0)
Imports: graphics, grDevices
Suggests: tinytest, covr
Encoding: UTF-8
RoxygenNote: 7.3.3
Language: en-US
URL: https://github.com/riatelab/maplegend/
BugReports: https://github.com/riatelab/maplegend/issues/
NeedsCompilation: no
Packaged: 2026-04-30 08:00:58 UTC; tim
Author: Timothée Giraud [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-1932-3323>)
Maintainer: Timothée Giraud <timothee.giraud@cnrs.fr>
Repository: CRAN
Date/Publication: 2026-04-30 10:00:02 UTC
